@@ -11,6 +11,7 @@ from alfa_sdk.common.exceptions import (
     ResourceNotFoundError,
     AuthenticationError,
     AuthorizationError,
+    ValidationError
 )
 
 
@@ -29,7 +30,6 @@ class Session:
         options = self.auth.authenticate_request({})
         self.http_session = requests.Session()
         self.http_session.headers.update(options["headers"])
-        self.http_session.params.update(options["params"])
 
     def request(self, method, service, path, *, parse=True, **kwargs):
         url = self.endpoint.resolve(service, path)
@@ -80,15 +80,27 @@ def parse_response(res):
         if isinstance(data["error"], collections.Mapping):
             error = data.get("error")
 
+            if "code" in error:
+                if error["code"] == "RESOURCE_NOT_FOUND":
+                    raise ResourceNotFoundError(url=url, error=str(error))
+                if error["code"] == "MISSING_TOKEN" or error["code"] == "INVALID_TOKEN":
+                    raise AuthenticationError(error=str(error))
+                if error["code"] == "UNAUTHORIZED" or error["code"] == "ACCESS_DENIED":
+                    raise AuthorizationError(url=url, error=str(error))
+                if error["code"] == "VALIDATION_FAILED":
+                    raise ValidationError(error=str(error))
+
+            # backward compatibility
             if "message" in error:
                 if error["message"].startswith("No token provided"):
                     raise AuthenticationError(error=str(error))
                 if error["message"].startswith("Error checking token"):
                     raise AuthenticationError(error=str(error))
 
+            # backward compatibility
             if "name" in error:
                 if error["name"] == "ModelNotFoundError":
-                    raise ResourceNotFoundError(url=url)
+                    raise ResourceNotFoundError(url=url, error=error.get("message"))
                 if error["name"] == "AuthorizationError":
                     raise AuthorizationError(url=url, error=error.get("message"))
 
@@ -135,6 +147,7 @@ def fetch_context(context):
         return context
 
     env_context = os.environ.get("ALFA_CONTEXT")
+    
     try:
         env_context = json.loads(env_context)
     except:
@@ -151,9 +164,12 @@ def append_credentials(credentials, context):
         return credentials
 
     if "accessToken" in context:
-        credentials["access_token"] = context.get("accessToken")
+        credentials["token"] = context.get("accessToken")
 
     if "auth0Token" in context:
-        credentials["auth0_token"] = context.get("auth0Token")
+        credentials["token"] = context.get("auth0Token")
+
+    if "token" in context:
+        credentials["token"] = context.get("token")
 
     return credentials
