@@ -20,5 +20,19 @@ class DataClient(BaseClient):
             "get",
             "data",
             "/api/Storages/list",
-            params={"prefix": prefix, "skip": skip, "limit": limit, "order": order},
+            params={
+                "prefix": prefix,
+                "skip": skip,
+                "limit": limit,
+                "order": order,
+                "teamId": self.team_id,
+            },
+        )
+
+    def update_data_file(self, data_file_id, changes):
+        return self.session.request(
+            "put",
+            "data",
+            "/api/Storages/update/{}".format(data_file_id),
+            json={"updates": changes},
         )
