@@ -1,5 +1,6 @@
+from datetime import datetime
 from alfa_sdk.common.base import BaseResource
-from alfa_sdk.common.exceptions import ResourceDeletionError
+from alfa_sdk.common.exceptions import ResourceDeletionError, ValidationError
 from alfa_sdk.common.helpers import VersionHelper
 from alfa_sdk import resources
 
@@ -154,3 +155,33 @@ class AlgorithmEnvironment(BaseResource):
         return self.session.request(
             "get", "meta", "/api/Units/getUnitsForAlgorithmEnvironment", params=params
         )
+
+    #
+
+    def store_kpi(self, kpis, entity=None, run_id=None, time=None):
+        if run_id is None:
+            raise ValidationError(error="AlgorithmRunId is not defined.")
+
+        if time is None:
+            time = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.000Z")
+
+        if not isinstance(kpis, list):
+            kpis = [kpis]
+
+        for kpi in kpis:
+            if not "time" in kpi:
+                kpi["time"] = time
+            if not "entity" in kpi:
+                kpi["entity"] = entity
+            if not "name" in kpi:
+                raise ValidationError(error="No name for KPI defined.")
+            if not "value" in kpi:
+                raise ValidationError(error="No value for KPI defined.")
+
+        body = {
+            "algorithmEnvironmentId": self.id,
+            "algorithmRunId": run_id,
+            "data": kpis,
+        }
+
+        return self.session.request("POST", "watch", "/api/kpis/add", json=body)
