@@ -1,6 +1,8 @@
+import os
 import requests
 
 from alfa_sdk.common.base import BaseResource
+from alfa_sdk.common.exceptions import ResourceNotFoundError, AlfaError
 from alfa_sdk import resources
 
 
@@ -11,10 +13,21 @@ class MetaUnit(BaseResource):
         super().__init__(**kwargs)
 
     def _fetch_data(self):
-        body = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
-        return self.session.request(
-            "get", "meta", "/api/Units/getUnitForAlgorithmEnvironment", json=body
-        )
+        self.local = self.session.context.get("__RUN_LOCAL__", False)
+        try:
+            body = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
+            return self.session.request(
+                "get", "meta", "/api/Units/getUnitForAlgorithmEnvironment", json=body
+            )
+        except AlfaError as err:
+            if self.local:
+                return {
+                    "id": None,
+                    "description": "",
+                    "buildConfigurations": [],
+                    "watchConfigurations": [],
+                }
+            raise err
 
     def _fill_data(self):
         data = self.get_data()
@@ -29,14 +42,42 @@ class MetaUnit(BaseResource):
         return resources.AlgorithmEnvironment(self.environment_id, session=self.session)
 
     def get_active_instance(self):
+        if self.local:
+            instances = self.list_instances()
+            if instances:
+                active_instance = max(instances, key=lambda x: x["id"])
+                return LocalMetaInstance(active_instance["path"])
+
         body = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
         data = self.session.request(
             "get", "meta", "/api/Units/getActiveInstance", json=body
         )
-
         return MetaInstance(data["id"], data=data, session=self.session)
 
     def list_instances(self):
+        if self.local:
+            instances_dir = os.path.join(
+                ".", "build", ".instances", *self.environment_id.split(":"), self.tag
+            )
+            if not os.path.isdir(instances_dir):
+                instances_dir = os.path.join(
+                    ".", "build", ".instances", self.environment_id, self.tag
+                )
+                if not os.path.isdir(instances_dir):
+                    return []
+
+            return sorted(
+                [
+                    {
+                        "id": os.path.splitext(f)[0],
+                        "path": os.path.join(instances_dir, f),
+                    }
+                    for f in os.listdir(instances_dir)
+                    if os.path.isfile(os.path.join(instances_dir, f))
+                ],
+                key=lambda x: x["id"],
+            )
+
         params = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
         return self.session.request(
             "get", "meta", "/api/Units/getAlgorithmInstances", params=params
@@ -46,7 +87,11 @@ class MetaUnit(BaseResource):
         params = {"algorithmEnvironmentId": self.environment_id, "tag": self.tag}
         files = {"file": open(file_path, "rb")}
         return self.session.request(
-            "post", "meta", "/api/Units/storeActivateInstance", params=params, files=files
+            "post",
+            "meta",
+            "/api/Units/storeActivateInstance",
+            params=params,
+            files=files,
         )
 
     def store_instance(self, file):
@@ -60,6 +105,7 @@ class MetaUnit(BaseResource):
             "post", "meta", "/api/Units/storeInstance", params=params, files=files
         )
 
+
 class MetaInstance(BaseResource):
     def __init__(self, instance_id, **kwargs):
         self.id = instance_id
@@ -89,3 +135,19 @@ class MetaInstance(BaseResource):
 
         res = requests.get(url, allow_redirects=True)
         return res.content
+
+
+class LocalMetaInstance(BaseResource):
+    def __init__(self, path, **kwargs):
+        self.path = path
+        self._data = kwargs.get("data", {})
+
+    def _fetch_data(self):
+        pass
+
+    def _fill_data(self):
+        pass
+
+    def fetch_file(self):
+        with open(self.path, "rb") as instance_file:
+            return instance_file.read()
